package com.fs.hisStore.service;

import com.fs.his.param.FsStoreAuditParam;
import com.fs.hisStore.domain.FsStoreScrm;
import com.fs.hisStore.vo.FsStoreRecommendListVO;
import com.fs.hisStore.vo.FsStoreScrmVO;

import java.util.List;


/**
 * 店铺管理Service接口
 *
 * @author fs
 * @date 2023-06-15
 */
public interface IFsStoreScrmService
{
    /**
     * 查询店铺管理
     *
     * @param storeId 店铺管理主键
     * @return 店铺管理
     */
    public FsStoreScrm selectFsStoreByStoreId(Long storeId);

    public List<FsStoreScrm> selectFsStoreByStoreIds(String[] storeId);

    /**
     * 查询店铺管理列表
     *
     * @param fsStore 店铺管理
     * @return 店铺管理集合
     */
    public List<FsStoreScrm> selectFsStoreList(FsStoreScrm fsStore);

    /**
     * 新增店铺管理
     *
     * @param fsStore 店铺管理
     * @return 结果
     */
    public Long insertFsStore(FsStoreScrm fsStore);

    /**
     * 修改店铺管理
     *
     * @param fsStore 店铺管理
     * @return 结果
     */
    public int updateFsStore(FsStoreScrm fsStore);

    /**
     * 批量删除店铺管理
     *
     * @param storeIds 需要删除的店铺管理主键集合
     * @return 结果
     */
    public int deleteFsStoreByStoreIds(Long[] storeIds);

    /**
     * 删除店铺管理信息
     *
     * @param storeId 店铺管理主键
     * @return 结果
     */
    public int deleteFsStoreByStoreId(Long storeId);

    int updateFsStoreAudit(FsStoreAuditParam fsStore);

    int updateFsStoreLogo(FsStoreScrm fsStore);

    int updateEditData(FsStoreScrm fsStore);


    List<FsStoreScrm> selectFsStoreListByDoctorId(Long doctorId);

    int refreshFsStore(Long storeId);

    List<FsStoreScrm> selectOverList();

    int batchUpdateStatusByIds(List<Long> ids, Integer status);

    List<FsStoreRecommendListVO> storeRecommendList();

    List<FsStoreScrmVO> selectAllStore();
}
